@@ -1,10 +1,11 @@
 import types
 import six
+import inspect
 import re
 from warnings import warn
 
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 __author__ = 'Philipp Sommer'
 
@@ -65,12 +66,16 @@ def safe_modulo(s, meta, checked='', print_warning=True, stacklevel=2):
     --------
     The effects are demonstrated by this example::
 
-        >>> from psyplot.docstring import safe_modulo
+        >>> from docrep import safe_modulo
         >>> s = "That's %(one)s string %(with)s missing 'with' and %s key"
-        >>> s % {'one': 1}
-        # raises KeyError because of missing 'with'
-        >>> s % {'one': 1, 'with': 2}
-        # raises TypeError because of '%s'
+        >>> s % {'one': 1}          # raises KeyError because of missing 'with'
+        Traceback (most recent call last):
+          File "<stdin>", line 1, in <module>
+        KeyError: 'with'
+        >>> s % {'one': 1, 'with': 2}        # raises TypeError because of '%s'
+        Traceback (most recent call last):
+          File "<stdin>", line 1, in <module>
+        TypeError: not enough arguments for format string
         >>> safe_modulo(s, {'one': 1})
         "That's 1 string %(with)s missing 'with' and %s key"
     """
@@ -110,7 +115,7 @@ class DocstringProcessor(object):
     --------
     Create docstring processor via::
 
-        >>> from psyplot.docstring import DocstringProcessor
+        >>> from docrep import DocstringProcessor
         >>> d = DocstringProcessor(doc_key='My doc string')
 
     And then use it as a decorator to process the docstring::
@@ -121,7 +126,7 @@ class DocstringProcessor(object):
         ...     pass
 
         >>> print(doc_test.__doc__)
-        That's my doc string
+        That's My doc string
 
     Use the :meth:`get_sectionsf` method to extract Parameter sections (or
     others) form the docstring for later usage (and make sure, that the
@@ -164,14 +169,14 @@ class DocstringProcessor(object):
         >>> print(second_test.__doc__)
         My second function where I want to use the docstring from
         above
-
+        <BLANKLINE>
         Parameters
         ----------
         a: int, optional
             A dummy parameter description
         b: int, optional
             A second dummy parameter
-
+        <BLANKLINE>
         Examples
         --------
         Some dummy example doc
@@ -222,6 +227,19 @@ class DocstringProcessor(object):
     text_sections = ['Warnings', 'Notes', 'Examples', 'See Also',
                      'References']
 
+    #: The action on how to react on classes in python 2
+    #:
+    #: When calling::
+    #:
+    #:     >>> @docstrings
+    #:     ... class NewClass(object):
+    #:     ...     """%(replacement)s"""
+    #:
+    #: This normaly raises an AttributeError, because the ``__doc__`` attribute
+    #: of a class in python 2 is not writable. This attribute may be one of
+    #: ``'ignore', 'raise' or 'warn'``
+    python2_classes = 'ignore'
+
     def __init__(self, *args, **kwargs):
         """
     Parameters
@@ -252,9 +270,22 @@ class DocstringProcessor(object):
         self.patterns = patterns
 
     def __call__(self, func):
-        func.__doc__ = func.__doc__ and safe_modulo(func.__doc__, self.params,
-                                                    stacklevel=3)
-        return func
+        """
+        Substitute in a docstring of a function with :attr:`params`
+
+        Parameters
+        ----------
+        func: function
+            function with the documentation whose sections
+            shall be inserted from the :attr:`params` attribute
+
+        See Also
+        --------
+        dedent: also dedents the doc
+        with_indent: also indents the doc"""
+        doc = func.__doc__ and safe_modulo(func.__doc__, self.params,
+                                           stacklevel=3)
+        return self._set_object_doc(func, doc)
 
     def get_sections(self, s, base,
                      sections=['Parameters', 'Other Parameters']):
@@ -338,6 +369,23 @@ class DocstringProcessor(object):
             return f
         return func
 
+    def _set_object_doc(self, obj, doc, stacklevel=3):
+        """Convenience method to set the __doc__ attribute of a python object
+        """
+        if isinstance(obj, types.MethodType) and six.PY2:
+            obj = obj.im_func
+        try:
+            obj.__doc__ = doc
+        except AttributeError:  # probably python2 class
+            if (self.python2_classes != 'raise' and
+                    (inspect.isclass(obj) and six.PY2)):
+                if self.python2_classes == 'warn':
+                    warn("Cannot modify docstring of classes in python2!",
+                         stacklevel=stacklevel)
+            else:
+                raise
+        return obj
+
     def dedent(self, func):
         """
         Dedent the docstring of a function and substitute with :attr:`params`
@@ -347,11 +395,8 @@ class DocstringProcessor(object):
         func: function
             function with the documentation to dedent and whose sections
             shall be inserted from the :attr:`params` attribute"""
-        if isinstance(func, types.MethodType) and not six.PY3:
-            func = func.im_func
-        func.__doc__ = func.__doc__ and self.dedents(func.__doc__,
-                                                     stacklevel=4)
-        return func
+        doc = func.__doc__ and self.dedents(func.__doc__, stacklevel=4)
+        return self._set_object_doc(func, doc)
 
     def dedents(self, s, stacklevel=3):
         """
@@ -369,15 +414,51 @@ class DocstringProcessor(object):
         return safe_modulo(s, self.params, stacklevel=stacklevel)
 
     def with_indent(self, indent=0):
+        """
+        Substitute in the docstring of a function with indented :attr:`params`
+
+        Parameters
+        ----------
+        indent: int
+            The number of spaces that the substitution should be indented
+
+        Returns
+        -------
+        function
+            Wrapper that takes a function as input and substitutes it's
+            ``__doc__`` with the indented versions of :attr:`params`
+
+        See Also
+        --------
+        with_indents, dedent"""
         def replace(func):
-            if isinstance(func, types.MethodType) and not six.PY3:
-                func = func.im_func
-            func.__doc__ = func.__doc__ and self.with_indents(
+            doc = func.__doc__ and self.with_indents(
                 func.__doc__, indent=indent, stacklevel=4)
-            return func
+            return self._set_object_doc(func, doc)
         return replace
 
     def with_indents(self, s, indent=0, stacklevel=3):
+        """
+        Substitute a string with the indented :attr:`params`
+
+        Parameters
+        ----------
+        s: str
+            The string in which to substitute
+        indent: int
+            The number of spaces that the substitution should be indented
+        stacklevel: int
+            The stacklevel for the warning raised in :func:`safe_module` when
+            encountering an invalid key in the string
+
+        Returns
+        -------
+        str
+            The substituted string
+
+        See Also
+        --------
+        with_indent, dedents"""
         # we make a new dictionary with objects that indent the original
         # strings if necessary. Note that the first line is not indented
         d = {key: _StrWithIndentation(val, indent)
